# 📝 TODO

- [ ] **Feature**| Support more single-table data synthetic models
  - [ ] OCT-GAN Model
  - [ ] CTAB-GAN Model
  - [ ] Table-GAN Model

# 🚧 Doing

- [ ] **Feature**| Support multi-table data synthesis
- [ ] **Feature**| Support more single-table data synthetic models - TVAE Model

# ✅ Done

- [x] **Enhance**| Hundred Thousand Level Discrete Data supported Gaussian Copula
- [x] **Docs**| Improved CONTRIBUTING documentation with 4+1 view and overview diagram
- [x] **Enhance**| Automatic identification and handling of fixed relationships
- [x] **Feature**| Support for single-table data synthesis based on CTGAN
- [x] **Feature**| Support for single-table data synthesis based on GaussianCopula
- [x] **Feature**| Support for single-table data synthesis without real data based on LLM
- [x] **Enhance**| Billion-Level-Data supported CTGAN
- [x] **Enhance**| Numeric Data Inspection and introduce positive/negative filtering
- [x] **Enhance**| Add NonValueTransformer reverse conversion with NAN_VALUE replacement
- [x] **Enhance**| Add ConstInspector and ConstValueTransformer for handling constant columns
- [x] **Enhance**| Data handling with empty column inspector and transformer
- [x] **Enhance**| Add ChnPiiGenerator and enhance models

# 🌟 Longterm

- [ ] **Feature**| Establishing an evaluation system for privacy metric
- [ ] **Feature**| Establishing an evaluation system for synthesis quality metric
